@@ -2,7 +2,7 @@ from ._version import __version__
 from .basic import Foo, Bar, Baz, Qux
 from .headers import (
     Y,
-    Xy,
+    Xyz,
     MyFormat,
     MyFormatGz,
     MyFormatGzX,
